@@ -10,6 +10,7 @@
 #include <vector>
 
 #include "gtest/gtest.h"
+#include "gtest_mpi.hpp"
 #include "memory/allocator_collection.hpp"
 #include "memory/buffer.hpp"
 #include "memory/host_array_const_view.hpp"
@@ -154,22 +155,20 @@ static auto find_rectangle(int n) -> std::pair<int, int> {
   return {n, 1};
 }
 
-// numThreads, rowBlockSize, colBlockSize, colsA, colsB, numLocalRows
 template <typename T>
 class GemmSBSTest
     : public ::testing::TestWithParam<
-          std::tuple<SplaProcessingUnit, int, int, int, std::pair<int, int>, int, int>> {
+          std::tuple<SplaProcessingUnit, int, int, std::pair<int, int>, int, int>> {
 protected:
   GemmSBSTest()
-      : rowBlockSize_(std::get<2>(GetParam())),
-        colBlockSize_(std::get<3>(GetParam())),
+      : rowBlockSize_(std::get<1>(GetParam())),
+        colBlockSize_(std::get<2>(GetParam())),
         m_(0),
-        n_(std::get<5>(GetParam())),
-        k_(std::get<6>(GetParam())),
+        n_(std::get<4>(GetParam())),
+        k_(std::get<5>(GetParam())),
         ctx_(std::get<0>(GetParam())) {
-    ctx_.set_num_threads(std::get<1>(GetParam()));
 
-    const std::pair<int, int> mRange = std::get<4>(GetParam());
+    const std::pair<int, int> mRange = std::get<3>(GetParam());
     std::uniform_int_distribution<int> mLocalDistribution(mRange.first, mRange.second);
 
     // generate local m size within range
@@ -331,6 +330,7 @@ typedef GemmSBSTest<double> GemmSBSScalar;
 typedef GemmSBSTest<std::complex<double>> GemmSBSComplex;
 
 TEST_P(GemmSBSScalar, FlatGrid) {
+  GTEST_MPI_GUARD
   try {
     auto desc = MatrixDistribution::create_blacs_block_cyclic(MPI_COMM_WORLD, 'R', mpi_world_size(),
                                                               1, rowBlockSize_, colBlockSize_);
@@ -342,6 +342,7 @@ TEST_P(GemmSBSScalar, FlatGrid) {
 }
 
 TEST_P(GemmSBSComplex, FlatGrid) {
+  GTEST_MPI_GUARD
   try {
     auto desc = MatrixDistribution::create_blacs_block_cyclic(MPI_COMM_WORLD, 'R', mpi_world_size(),
                                                               1, rowBlockSize_, colBlockSize_);
@@ -353,6 +354,7 @@ TEST_P(GemmSBSComplex, FlatGrid) {
 }
 
 TEST_P(GemmSBSScalar, SquareGrid) {
+  GTEST_MPI_GUARD
   try {
     int gridRows, gridCols;
     std::tie(gridRows, gridCols) = find_rectangle(mpi_world_size());
@@ -367,6 +369,7 @@ TEST_P(GemmSBSScalar, SquareGrid) {
 }
 
 TEST_P(GemmSBSComplex, SquareGrid) {
+  GTEST_MPI_GUARD
   try {
     int gridRows, gridCols;
     std::tie(gridRows, gridCols) = find_rectangle(mpi_world_size());
@@ -381,6 +384,7 @@ TEST_P(GemmSBSComplex, SquareGrid) {
 }
 
 TEST_P(GemmSBSScalar, SquareGridOffset) {
+  GTEST_MPI_GUARD
   try {
     int gridRows, gridCols;
     std::tie(gridRows, gridCols) = find_rectangle(mpi_world_size());
@@ -395,6 +399,7 @@ TEST_P(GemmSBSScalar, SquareGridOffset) {
 }
 
 TEST_P(GemmSBSComplex, SquareGridOffset) {
+  GTEST_MPI_GUARD
   try {
     int gridRows, gridCols;
     std::tie(gridRows, gridCols) = find_rectangle(mpi_world_size());
@@ -409,6 +414,7 @@ TEST_P(GemmSBSComplex, SquareGridOffset) {
 }
 
 TEST_P(GemmSBSScalar, Mirror) {
+  GTEST_MPI_GUARD
   try {
     auto desc = MatrixDistribution::create_mirror(MPI_COMM_WORLD);
     multiply(desc, 0, 0);
@@ -419,6 +425,7 @@ TEST_P(GemmSBSScalar, Mirror) {
 }
 
 TEST_P(GemmSBSComplex, Mirror) {
+  GTEST_MPI_GUARD
   try {
     auto desc = MatrixDistribution::create_mirror(MPI_COMM_WORLD);
     multiply(desc, 0, 0);
@@ -429,6 +436,7 @@ TEST_P(GemmSBSComplex, Mirror) {
 }
 
 TEST_P(GemmSBSScalar, MirrorOffset) {
+  GTEST_MPI_GUARD
   try {
     auto desc = MatrixDistribution::create_mirror(MPI_COMM_WORLD);
     multiply(desc, 2, 3);
@@ -439,6 +447,7 @@ TEST_P(GemmSBSScalar, MirrorOffset) {
 }
 
 TEST_P(GemmSBSComplex, MirrorOffset) {
+  GTEST_MPI_GUARD
   try {
     auto desc = MatrixDistribution::create_mirror(MPI_COMM_WORLD);
     multiply(desc, 2, 3);
@@ -450,7 +459,7 @@ TEST_P(GemmSBSComplex, MirrorOffset) {
 
 static auto param_type_names(
     const ::testing::TestParamInfo<
-        std::tuple<SplaProcessingUnit, int, int, int, std::pair<int, int>, int, int>>& info)
+        std::tuple<SplaProcessingUnit, int, int, std::pair<int, int>, int, int>>& info)
     -> std::string {
   std::stringstream stream;
   if (std::get<0>(info.param) == SplaProcessingUnit::SPLA_PU_HOST) {
@@ -458,25 +467,23 @@ static auto param_type_names(
   } else {
     stream << "GPU_";
   }
-  stream << "t_" << std::to_string(std::get<1>(info.param)) << "_";
-  stream << "mb_" << std::to_string(std::get<2>(info.param)) << "_";
-  stream << "nb_" << std::get<3>(info.param) << "_";
-  stream << "mMin_" << std::get<4>(info.param).first << "_";
-  stream << "mMax_" << std::get<4>(info.param).second << "_";
-  stream << "n_" << std::get<5>(info.param) << "_";
-  stream << "k_" << std::get<6>(info.param);
+  stream << "mb_" << std::to_string(std::get<1>(info.param)) << "_";
+  stream << "nb_" << std::get<2>(info.param) << "_";
+  stream << "mMin_" << std::get<3>(info.param).first << "_";
+  stream << "mMax_" << std::get<3>(info.param).second << "_";
+  stream << "n_" << std::get<4>(info.param) << "_";
+  stream << "k_" << std::get<5>(info.param);
 
   return stream.str();
 }
 
-INSTANTIATE_TEST_CASE_P(GemmSBS, GemmSBSScalar,
+INSTANTIATE_TEST_SUITE_P(GemmSBS, GemmSBSScalar,
                         ::testing::Combine(::testing::Values(SplaProcessingUnit::SPLA_PU_HOST
 #if defined(SPLA_CUDA) || defined(SPLA_ROCM)
                                                              ,
                                                              SplaProcessingUnit::SPLA_PU_GPU
 #endif
                                                              ),
-                                           ::testing::Values(1, 4),   // number of threads
                                            ::testing::Values(1, 64),  // row block size
                                            ::testing::Values(1, 64),  // coloumn block size
                                            ::testing::Values(std::pair<int, int>(0, 1),
@@ -486,14 +493,13 @@ INSTANTIATE_TEST_CASE_P(GemmSBS, GemmSBSScalar,
                                            ::testing::Values(1, 13, 32, 263)),           // k
                         param_type_names);
 
-INSTANTIATE_TEST_CASE_P(GemmSBS, GemmSBSComplex,
+INSTANTIATE_TEST_SUITE_P(GemmSBS, GemmSBSComplex,
                         ::testing::Combine(::testing::Values(SplaProcessingUnit::SPLA_PU_HOST
 #if defined(SPLA_CUDA) || defined(SPLA_ROCM)
                                                              ,
                                                              SplaProcessingUnit::SPLA_PU_GPU
 #endif
                                                              ),
-                                           ::testing::Values(1, 4),   // number of threads
                                            ::testing::Values(1, 64),  // row block size
                                            ::testing::Values(1, 64),  // coloumn block size
                                            ::testing::Values(std::pair<int, int>(0, 1),
@@ -503,14 +509,13 @@ INSTANTIATE_TEST_CASE_P(GemmSBS, GemmSBSComplex,
                                            ::testing::Values(1, 13, 32, 263)),           // k
                         param_type_names);
 
-INSTANTIATE_TEST_CASE_P(LargeGemmSBS, GemmSBSScalar,
+INSTANTIATE_TEST_SUITE_P(LargeGemmSBS, GemmSBSScalar,
                         ::testing::Combine(::testing::Values(SplaProcessingUnit::SPLA_PU_HOST
 #if defined(SPLA_CUDA) || defined(SPLA_ROCM)
                                                              ,
                                                              SplaProcessingUnit::SPLA_PU_GPU
 #endif
                                                              ),
-                                           ::testing::Values(2),    // number of threads
                                            ::testing::Values(128),  // row block size
                                            ::testing::Values(128),  // coloumn block size
                                            ::testing::Values(std::pair<int, int>(50,
